package cn.estsh.i3plus.ext.mes.pcn.apiservice.schedulejob.gz;

import cn.estsh.i3plus.ext.mes.pcn.api.job.gz.IGzThirdPartyDbCollectDataJobService;
import cn.estsh.i3plus.ext.mes.pcn.pojo.util.MesPcnExtConstWords;
import io.swagger.annotations.ApiOperation;
import org.jboss.logging.Logger;
import org.quartz.DisallowConcurrentExecution;
import org.quartz.Job;
import org.quartz.JobExecutionContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;

/**
 * @author wangjie
 * @version 1.0
 * @date 2021/2/2 16:44
 **/
@DisallowConcurrentExecution
@ApiOperation("第三方数据库数据采集定时任务")
public class GzThirdPartyDbCollectDataJob implements Job {

    private static final Logger LOGGER = Logger.getLogger(GzThirdPartyDbCollectDataJob.class);

    @Autowired
    private IGzThirdPartyDbCollectDataJobService thirdPartyDbCollectDataJobService;

    @Override
    public void execute(JobExecutionContext jobExecutionContext) {
        LOGGER.info("Pcn处理第三方数据库数据采集JOB开始执行...");

        Object param = jobExecutionContext.getJobDetail().getJobDataMap().get(MesPcnExtConstWords.PARAM);
        if (StringUtils.isEmpty(param)) {
            LOGGER.error("Pcn处理第三方数据库数据采集JOB,未配置参数");
            return;
        }

        String[] paramArr = param.toString().split(MesPcnExtConstWords.COMMA);
        if (paramArr.length != 2) {
            LOGGER.error("Pcn处理第三方数据库数据采集JOB,配置的参数无效");
            return;
        }

        long startTime = System.currentTimeMillis();

        thirdPartyDbCollectDataJobService.doThirdPartyDbCollectData(paramArr[0], paramArr[1], MesPcnExtConstWords.JOB);

        long endTime = System.currentTimeMillis();
        LOGGER.info("Pcn处理第三方数据库数据采集JOB执行完成耗时: " + (endTime - startTime) + "ms");

    }
}
